@@ -445,11 +445,11 @@ class HybridAppCommand(discord.app_commands.Command[CogT, P, T]):
             else:
                 exc = HybridCommandError(e)
                 exc.__cause__ = e
-            await command.dispatch_error(ctx, exc)
+            await command.dispatch_error(ctx, exc.with_traceback(e.__traceback__))
         except app_commands.AppCommandError as e:
             exc = HybridCommandError(e)
             exc.__cause__ = e
-            await command.dispatch_error(ctx, exc)
+            await command.dispatch_error(ctx, exc.with_traceback(e.__traceback__))
         except CommandError as e:
             await command.dispatch_error(ctx, e)
         finally:
@@ -706,6 +706,11 @@ class HybridGroup(Group[CogT, P, T]):
             # This is a very lazy copy because the CogMeta will properly copy it
             # with bindings and all later
             copy.app_command._children = self.app_command._children.copy()
+
+        # Ensure the copy's fallback wraps the copy
+        if copy._fallback_command and self._fallback_command:
+            copy._fallback_command.wrapped = copy
+
         return copy
 
     def autocomplete(
@@ -903,6 +908,9 @@ def hybrid_group(
 
     Parameters
     -----------
+    name: Union[:class:`str`, :class:`~discord.app_commands.locale_str`]
+        The name to create the group with. By default this uses the
+        function name unchanged.
     with_app_command: :class:`bool`
         Whether to register the command also as an application command.
 
